=============
Django-Twilio
=============


Integrate Twilio into your Django apps with ease.

.. image:: https://badge.fury.io/py/django-twilio.png
    :target: http://badge.fury.io/py/django-twilio
    :alt: PyPI version
.. image:: https://travis-ci.org/rdegges/django-twilio.png?branch=master
    :target: https://travis-ci.org/rdegges/django-twilio
    :alt: CI build
.. image:: https://readthedocs.org/projects/django-twilio/badge/?version=latest
    :target: https://readthedocs.org/projects/django-twilio/badge/?version=latest
    :alt: documentation build
.. image:: https://img.shields.io/pypi/pyversions/django-twilio.svg
    :target:  https://pypi.python.org/pypi/django-twilio/
    :alt: Python versions supported


Meta
----

* Author: Randall Degges
* Email:  rdegges@gmail.com
* Maintainer: Jason Held
* Email: jasonsheld@gmail.com
* Status: active development, stable, maintained


Twilio makes it easy to send & receive SMS messages, and create & manage voice calls through software.

Django-twilio makes it easy to use Twilio in your Django projects.

This project aims to keep compatibility with the supported Django releases.

As such our versions of python and django are designed to match that cadence as much as possible.


We are currently compatible with Django 2.2 and 3.0. Python versions 3.5 to 3.8.

Documentation
-------------

The documentation is hosted at ReadTheDocs. You can check out the docs
here - http://django-twilio.rtfd.org/
